Emvqr class

Implementation of the EMV QR functionality using platform-specific methods.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

callbackResultStream() Stream
Retrieves a stream for receiving callback results.
getPlatformVersion() Future<String?>
Retrieves the version of the native platform.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scanQR() Future<ScanResult?>
Initiates a QR code scan operation.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Emvqr
Singleton instance of Emvqr.
getter/setter pair