MethodChannelEmvqr class

An implementation of EmvqrPlatform that uses method channels.

Inheritance

Constructors

MethodChannelEmvqr()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
Retrieves the version of the native platform.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scanQR() Future<ScanResult?>
Initiates a QR code scan operation.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited