EmvqrConstants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
SPEC_ID_MERCHANT_ID
→ List<
String> -
no setter
-
UNRESERVED_TEMPLATE_PARENT_IDS
→ List<
String> -
no setter
-
UNRESERVED_TEMPLATE_SUB_IDS
→ List<
String> -
no setter
Constants
- EVENT_CHANNEL_NAME → const String
- METHOD_CHANNEL_NAME → const String
- SPEC_ID_ADDITIONAL_INFO → const String
- SPEC_ID_AMOUNT → const String
- SPEC_ID_COUNTRY_CODE → const String
- SPEC_ID_CURRENCY → const String
- SPEC_ID_FEES_FIXED → const String
- SPEC_ID_FEES_PERCENTAGE → const String
- SPEC_ID_MCC → const String
- SPEC_ID_MERCHANT_CITY → const String
- SPEC_ID_MERCHANT_NAME → const String
- SPEC_ID_POSTAL_CODE → const String
- SPEC_ID_UN_RESERVED_TEMPLATE_80 → const String
- STATUS_COMPLETED → const String
- STATUS_ERROR → const String
- STATUS_STARTED → const String
- SUB_SPEC_ID_BILL_NUMBER → const String
- SUB_SPEC_ID_BRAND_ID → const String
- SUB_SPEC_ID_CUSTOMER_LABEL → const String
- SUB_SPEC_ID_LOYALTY_NUMBER → const String
- SUB_SPEC_ID_MOBILE_NUMBER → const String
- SUB_SPEC_ID_REFERENCE_LABEL → const String
- SUB_SPEC_ID_STORE_ID → const String
- SUB_SPEC_ID_STORE_LABEL → const String
- SUB_SPEC_ID_TERMINAL_LABEL → const String
- SUB_SPEC_ID_TIMESTAMP → const String